@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Linear_cell_complex/demo/Linear_cell_complex/import_moka.h $
-// $Id: import_moka.h cc99fd9 2021-02-19T16:02:12+01:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Linear_cell_complex/demo/Linear_cell_complex/import_moka.h $
+// $Id: import_moka.h 999a813 2022-05-05T13:34:19+02:00 Guillaume Damiand
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -17,10 +17,10 @@ namespace CGAL
 struct GDart
 {
   unsigned int alpha[4];
-  Dart_handle dh;
-  LCC::Vertex_attribute_handle vh;
+  Dart_descriptor dh;
+  LCC::Vertex_attribute_descriptor vh;
 
-  GDart() : dh(nullptr), vh(nullptr)
+  GDart() : dh(LCC::null_descriptor), vh(LCC::null_descriptor)
   {}
 
   GDart(const GDart& adart) : dh(adart.dh),
@@ -97,9 +97,9 @@ bool import_from_moka(LCC& lcc, const char* filename)
   std::stack<unsigned int> totreat;
   for (unsigned int startingdart = 0; startingdart<nbLoaded; ++startingdart)
   {
-    bool orient=(gdarts[startingdart].dh==nullptr);
+    bool orient=(gdarts[startingdart].dh==LCC::null_descriptor);
     for (unsigned int dim=0; orient && dim<4; ++dim)
-      if (gdarts[gdarts[startingdart].alpha[dim]].dh!=nullptr) orient=false;
+      if (gdarts[gdarts[startingdart].alpha[dim]].dh!=LCC::null_descriptor) orient=false;
 
     if ( orient )
     {
@@ -111,15 +111,15 @@ bool import_from_moka(LCC& lcc, const char* filename)
         unsigned int i=totreat.top();
         totreat.pop();
 
-        assert(gdarts[i].dh!=nullptr);
+        assert(gdarts[i].dh!=LCC::null_descriptor);
 
         for (unsigned int dim=1; dim<4; ++dim)
         {
           if (gdarts[i].alpha[dim]!=i &&
-              gdarts[gdarts[i].alpha[dim]].vh!=nullptr)
+              gdarts[gdarts[i].alpha[dim]].vh!=LCC::null_descriptor)
           {
             gdarts[i].vh = gdarts[gdarts[i].alpha[dim]].vh;
-            gdarts[gdarts[i].alpha[dim]].vh = nullptr;
+            gdarts[gdarts[i].alpha[dim]].vh = LCC::null_descriptor;
           }
 
           unsigned int alpha0 = gdarts[i].alpha[0];
@@ -127,7 +127,7 @@ bool import_from_moka(LCC& lcc, const char* filename)
 
           if (gdarts[alpha0].alpha[dim]!=alpha0)
           {
-            if ( gdarts[gdarts[alpha0].alpha[dim]].dh==nullptr )
+            if ( gdarts[gdarts[alpha0].alpha[dim]].dh==LCC::null_descriptor )
             {
               totreat.push(gdarts[alpha0].alpha[dim]);
               gdarts[gdarts[alpha0].alpha[dim]].dh = lcc.create_dart();
@@ -151,13 +151,13 @@ bool import_from_moka(LCC& lcc, const char* filename)
   bool orientable = true;
   for (unsigned int i = 0; i<nbLoaded; ++i)
   {
-    if (gdarts[i].dh!=nullptr)
+    if (gdarts[i].dh!=LCC::null_descriptor)
     {
       for (unsigned int dim=0; dim<4; ++dim)
       {
         if (orientable &&
             gdarts[i].alpha[dim]!=i &&
-            gdarts[gdarts[i].alpha[dim]].dh!=nullptr)
+            gdarts[gdarts[i].alpha[dim]].dh!=LCC::null_descriptor)
         {
           std::cout<<"Pb, the gmap is NOT orientable."<<std::endl;
           orientable=false;
@@ -165,12 +165,12 @@ bool import_from_moka(LCC& lcc, const char* filename)
         }
       }
 
-      if ( lcc.template attribute<3>(gdarts[i].dh) == nullptr )
+      if ( lcc.template attribute<3>(gdarts[i].dh) == LCC::null_descriptor )
       {
         lcc.template set_attribute<3>(gdarts[i].dh, lcc.template create_attribute<3>());
       }
     }
-    if (gdarts[i].vh!=nullptr)
+    if (gdarts[i].vh!=LCC::null_descriptor)
     {
       lcc.set_vertex_attribute(gdarts[i].dh, gdarts[i].vh);
     }
