@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Combinatorial_map/include/CGAL/Dart_const_iterators.h $
-// $Id: Dart_const_iterators.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Combinatorial_map/include/CGAL/Dart_const_iterators.h $
+// $Id: Dart_const_iterators.h 999a813 2022-05-05T13:34:19+02:00 Guillaume Damiand
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -38,17 +38,17 @@ namespace CGAL {
     typedef CMap_dart_const_iterator_basic_of_orbit<Map_,Beta...> Self;
     typedef CMap_dart_iterator_basic_of_orbit_generic<Map_,true,Beta...> Base;
 
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
     typedef typename Map_::size_type size_type;
 
     /// Main constructor.
     CMap_dart_const_iterator_basic_of_orbit(const Map_& amap,
-                                            Dart_const_handle adart):
+                                            Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /// Main constructor.
     CMap_dart_const_iterator_basic_of_orbit(const Map_& amap,
-                                            Dart_const_handle adart,
+                                            Dart_const_descriptor adart,
                                             size_type amark):
       Base(amap,adart,amark)
     {}
@@ -69,11 +69,11 @@ namespace CGAL {
     typedef CMap_dart_const_iterator_of_orbit<Map_,Beta...> Self;
     typedef CMap_dart_iterator_of_orbit_generic<Map_,true,Beta...> Base;
 
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
 
     /// Main constructor.
     CMap_dart_const_iterator_of_orbit(const Map_& amap,
-                                      Dart_const_handle adart):
+                                      Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /// Constructor from non const version.
@@ -90,17 +90,17 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_basic_of_all<Map_,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
     typedef typename Map_::size_type size_type;
 
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_all(const Map_& amap,
-                                          Dart_const_handle adart):
+                                          Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_all(const Map_& amap,
-                                          Dart_const_handle adart,
+                                          Dart_const_descriptor adart,
                                           size_type /*amark*/):
       Base(amap,adart)
     {}
@@ -118,17 +118,17 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_basic_of_cell<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
     typedef typename Map_::size_type size_type;
 
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_cell(const Map_& amap,
-                                           Dart_const_handle adart):
+                                           Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_cell(const Map_& amap,
-                                           Dart_const_handle adart,
+                                           Dart_const_descriptor adart,
                                            size_type amark):
       Base(amap,adart,amark)
     {}
@@ -146,11 +146,11 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_of_cell<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
 
     /* Main constructor. */
     CMap_dart_const_iterator_of_cell(const Map_& amap,
-                                     Dart_const_handle adart):
+                                     Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /// Constructor from non const version.
@@ -167,17 +167,17 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_basic_of_involution<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
     typedef typename Map_::size_type size_type;
 
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_involution(const Map_& amap,
-                                                 Dart_const_handle adart):
+                                                 Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_involution(const Map_& amap,
-                                                 Dart_const_handle adart,
+                                                 Dart_const_descriptor adart,
                                                  size_type amark):
       Base(amap,adart,amark)
     {}
@@ -195,11 +195,11 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_of_involution<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
 
     /* Main constructor. */
     CMap_dart_const_iterator_of_involution(const Map_& amap,
-                                           Dart_const_handle adart):
+                                           Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /// Constructor from non const version.
@@ -216,17 +216,17 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_basic_of_involution_inv<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
     typedef typename Map_::size_type size_type;
 
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_involution_inv(const Map_& amap,
-                                                     Dart_const_handle adart):
+                                                     Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /* Main constructor. */
     CMap_dart_const_iterator_basic_of_involution_inv(const Map_& amap,
-                                                     Dart_const_handle adart,
+                                                     Dart_const_descriptor adart,
                                                      size_type amark):
       Base(amap,adart,amark)
     {}
@@ -244,11 +244,11 @@ namespace CGAL {
   {
   public:
     typedef CMap_dart_iterator_of_involution_inv<Map_,i,d,true> Base;
-    typedef typename Map_::Dart_const_handle Dart_const_handle;
+    typedef typename Map_::Dart_const_descriptor Dart_const_descriptor;
 
     /* Main constructor. */
     CMap_dart_const_iterator_of_involution_inv(const Map_& amap,
-                                               Dart_const_handle adart):
+                                               Dart_const_descriptor adart):
       Base(amap,adart)
     {}
     /// Constructor from non const version.
