@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Kernel_23/include/CGAL/Kernel/global_functions_3.h $
-// $Id: global_functions_3.h d3b26a6 2021-04-22T17:35:27+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Kernel_23/include/CGAL/Kernel/global_functions_3.h $
+// $Id: global_functions_3.h d16dfc3 2022-01-27T19:43:21+01:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -309,6 +309,15 @@ collinear_are_strictly_ordered_along_line(const Point_3<K> &p,
   return internal::collinear_are_strictly_ordered_along_line(p, q, r, K());
 }
 
+template < class K >
+inline
+typename K::Comparison_result
+compare_angle(const Point_3<K>& a, const Point_3<K>& b, const Point_3<K>& c,
+              const typename K::FT& cosine)
+{
+  return internal::compare_angle(a, b, c, cosine, K());
+}
+
 template < class K >
 inline
 typename K::Comparison_result
