@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Number_types/include/CGAL/Lazy_exact_nt.h $
-// $Id: Lazy_exact_nt.h 52b0779 2021-02-17T00:25:16+01:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Number_types/include/CGAL/Lazy_exact_nt.h $
+// $Id: Lazy_exact_nt.h 3674c93 2022-11-15T15:21:01+01:00 albert-github
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,9 +18,7 @@
 
 #include <CGAL/boost/iterator/transform_iterator.hpp> // for Root_of functor
 #include <boost/operators.hpp>
-#include <boost/type_traits/is_same.hpp>
 #include <boost/type_traits/is_arithmetic.hpp>
-#include <boost/utility/enable_if.hpp>
 
 #include <boost/mpl/if.hpp>
 #include <boost/mpl/logical.hpp>
@@ -37,6 +35,8 @@
 #include <CGAL/tss.h>
 #include <CGAL/type_traits.h>
 
+#include<type_traits>
+
 #include <CGAL/IO/io.h>
 
 #define CGAL_int(T)    typename First_if_different<int,    T>::Type
@@ -68,7 +68,7 @@
  * TODO :
  * - Generalize it for constructions at the kernel level.
  * - Add mixed operations with ET too ?
- * - Interval refinement functionnality ?
+ * - Interval refinement functionality ?
  * - Separate the handle and the representation(s) in 2 files (?)
  *   maybe not a good idea, better if everything related to one operation is
  *   close together.
@@ -174,7 +174,7 @@ struct Lazy_exact_Ex_Cst final : public Lazy_exact_nt_rep<ET>
   }
 };
 
-// Construction from a Lazy_exact_nt<ET1> (which keeps the lazyness).
+// Construction from a Lazy_exact_nt<ET1> (which keeps the laziness).
 template <typename ET, typename ET1>
 class Lazy_lazy_exact_Cst final : public Lazy_exact_nt_rep<ET>
 {
@@ -382,9 +382,9 @@ public :
 
   // Also check that ET and AT are constructible from T?
   template<class T>
-  Lazy_exact_nt (T i, typename boost::enable_if<boost::mpl::and_<
+  Lazy_exact_nt (T i, std::enable_if_t<boost::mpl::and_<
       boost::mpl::or_<boost::is_arithmetic<T>, std::is_enum<T> >,
-      boost::mpl::not_<boost::is_same<T,ET> > >,void*>::type=0)
+      boost::mpl::not_<std::is_same<T,ET> > >::value,void*> = 0)
     : Base(new Lazy_exact_Cst<ET,T>(i)) {}
 
   Lazy_exact_nt (const ET & e)
@@ -394,12 +394,12 @@ public :
 
   template <class ET1>
   Lazy_exact_nt (const Lazy_exact_nt<ET1> &x,
-      typename boost::enable_if<is_implicit_convertible<ET1,ET>,int>::type=0)
+      std::enable_if_t<is_implicit_convertible<ET1,ET>::value,int> = 0)
     : Base(new Lazy_lazy_exact_Cst<ET, ET1>(x)){}
 
   template <class ET1>
   explicit Lazy_exact_nt (const Lazy_exact_nt<ET1> &x,
-  typename boost::disable_if<is_implicit_convertible<ET1,ET>,int>::type=0)
+  typename std::enable_if_t<!is_implicit_convertible<ET1,ET>::value,int> = 0)
     : Base(new Lazy_lazy_exact_Cst<ET, ET1>(x)){}
 
   friend void swap(Lazy_exact_nt& a, Lazy_exact_nt& b) noexcept
@@ -944,7 +944,7 @@ struct Div_mod_selector {
     void operator()( const NT1& x, const NT2& y,
                      NT& q,
                      NT& r ) const {
-      CGAL_static_assertion((::boost::is_same<
+      CGAL_static_assertion((::std::is_same<
         typename Coercion_traits< NT1, NT2 >::Type, NT
                                               >::value));
 
@@ -1029,7 +1029,7 @@ template < typename ET > class Real_embeddable_traits< Lazy_exact_nt<ET> >
   : public INTERN_RET::Real_embeddable_traits_base< Lazy_exact_nt<ET> , CGAL::Tag_true > {
 
   // Every type ET of Lazy_exact_nt<ET> has to be real embeddable.
-  CGAL_static_assertion((::boost::is_same< typename Real_embeddable_traits< ET >
+  CGAL_static_assertion((::std::is_same< typename Real_embeddable_traits< ET >
                                 ::Is_real_embeddable, Tag_true >::value));
 
   public:
@@ -1178,7 +1178,7 @@ struct Coercion_traits< Lazy_exact_nt<ET1>, Lazy_exact_nt<ET2> >
         Are_implicit_interoperable;                                     \
     private:                                                            \
         static const  bool interoperable                                \
-        =boost::is_same< Are_implicit_interoperable, Tag_false>::value; \
+        =std::is_same< Are_implicit_interoperable, Tag_false>::value; \
     public:                                                             \
         typedef typename boost::mpl::if_c <interoperable,Null_tag,NT>   \
         ::type  Type;                                          \
