@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/BGL/include/CGAL/boost/graph/iterator.h $
-// $Id: iterator.h 320da5e 2020-11-18T07:43:12+00:00 Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/BGL/include/CGAL/boost/graph/iterator.h $
+// $Id: iterator.h 1b84329 2023-05-03T15:05:45+02:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -213,16 +213,10 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_source_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base() == nullptr)) ?
-      &Halfedge_around_source_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base() == nullptr));
   }
 
   bool operator==( const Self& i) const {
@@ -313,16 +307,10 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_target_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base() == nullptr)) ?
-      &Halfedge_around_target_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base() == nullptr));
   }
 
   bool operator==( const Self& i) const {
@@ -412,16 +400,9 @@ public:
   pointer           operator -> ( )       { return &pos; }
   const value_type* operator -> ( ) const { return &pos; }
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_face_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base() == nullptr)) ?
-      &Halfedge_around_face_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base() == nullptr));
   }
 
   bool operator==( const Self& i) const {
@@ -522,16 +503,10 @@ public:
   Halfedge_around_source_circulator(vertex_descriptor vd, const Graph& g)
     : Halfedge_around_source_circulator::iterator_adaptor_(Halfedge_around_target_circulator<Graph>(halfedge(vd,g),g)), opp(g)
   {}
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_source_circulator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Halfedge_around_source_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
@@ -539,6 +514,11 @@ public:
     return this->base_reference() == nullptr;
   }
 
+  bool operator!= (void*) const
+  {
+    return this->base_reference() != nullptr;
+  }
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::halfedge_descriptor dereference() const { return opp(*this->base_reference()); }
@@ -580,16 +560,9 @@ public:
 #ifndef DOXYGEN_RUNNING
   typedef std::size_t size_type;
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Face_around_target_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Face_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
@@ -597,6 +570,11 @@ public:
     return this->base_reference() == nullptr;
   }
 
+  bool operator!= (void*) const
+  {
+    return this->base_reference() != nullptr;
+  }
+
 
 private:
   friend class boost::iterator_core_access;
@@ -654,17 +632,9 @@ public:
   bool       operator == ( const Self& other) const { return  g == other.g && pos == other.pos; }
   bool       operator != ( const Self& other) const { return  g != other.g || pos != other.pos; }
 
-
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_target_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (g == nullptr)) ?
-      &Halfedge_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (g == nullptr));
   }
 
 
@@ -673,6 +643,11 @@ public:
     return g == nullptr;
   }
 
+  bool operator!= (void* ) const
+  {
+    return g != nullptr;
+  }
+
 
   Self& operator++()
   {
@@ -751,17 +726,9 @@ public:
   bool       operator == ( const Self& other) const { return  g == other.g && pos == other.pos; }
   bool       operator != ( const Self& other) const { return  g != other.g || pos != other.pos; }
 
-
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_face_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (g == nullptr)) ?
-      &Halfedge_around_face_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (g == nullptr));
   }
 
   bool operator== (void* ) const
@@ -769,6 +736,11 @@ public:
     return g == nullptr;
   }
 
+  bool operator!= (void* ) const
+  {
+    return g != nullptr;
+  }
+
   Self& operator++()
   {
     CGAL_assertion(g != nullptr);
@@ -980,6 +952,12 @@ faces_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h, co
   return make_range(I(h,g), I(h,g,1));
 }
 
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional circulator with value type `boost::graph_traits<Graph>::%vertex_descriptor` over all vertices incident to the same face or border.
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalIterator`
+ */
 template <typename Graph>
 class Vertex_around_face_circulator
 #ifndef DOXYGEN_RUNNING
@@ -1008,22 +986,22 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_face_circulator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Vertex_around_face_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
   {
     return this->base_reference()== nullptr;
   }
+
+  bool operator!= (void*) const
+  {
+    return this->base_reference()!= nullptr;
+  }
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
@@ -1062,16 +1040,10 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_face_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Vertex_around_face_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
@@ -1192,16 +1164,10 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_target_circulator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Vertex_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
@@ -1209,6 +1175,11 @@ public:
     return this->base_reference()== nullptr;
   }
 
+  bool operator!= (void*) const
+  {
+    return this->base_reference()!= nullptr;
+  }
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
@@ -1250,16 +1221,10 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_target_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Vertex_around_target_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 private:
   friend class boost::iterator_core_access;
@@ -1337,16 +1302,9 @@ public:
   Out_edge_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
     : Out_edge_iterator::iterator_adaptor_(Halfedge_around_target_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), opp(g) {}
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Out_edge_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &Out_edge_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
 
@@ -1379,16 +1337,9 @@ public:
     : In_edge_iterator::iterator_adaptor_(Halfedge_around_target_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), fct(g)
   {}
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (In_edge_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == nullptr)) ?
-      &In_edge_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
  private:
